@@ -36,36 +36,53 @@
 #include "Peer.h"
 #include "BtMessageDispatcher.h"
 #include "BtRequestFactory.h"
+#include "SocketBuffer.h"
 
 namespace aria2 {
 
-const std::string BtChokeMessage::NAME("choke");
+const char BtChokeMessage::NAME[] = "choke";
 
-SharedHandle<BtChokeMessage> BtChokeMessage::create
-(const unsigned char* data, size_t dataLength)
+BtChokeMessage::BtChokeMessage() : ZeroBtMessage{ID, NAME} {}
+
+std::unique_ptr<BtChokeMessage>
+BtChokeMessage::create(const unsigned char* data, size_t dataLength)
 {
   return ZeroBtMessage::create<BtChokeMessage>(data, dataLength);
 }
 
 void BtChokeMessage::doReceivedAction()
 {
-  if(_metadataGetMode) {
+  if (isMetadataGetMode()) {
     return;
   }
-  peer->peerChoking(true);
-  dispatcher->doChokedAction();
-  requestFactory->doChokedAction();
+  getPeer()->peerChoking(true);
+  getBtMessageDispatcher()->doChokedAction();
+  getBtRequestFactory()->doChokedAction();
 }
 
-bool BtChokeMessage::sendPredicate() const
-{
-  return !peer->amChoking();
-}
+bool BtChokeMessage::sendPredicate() const { return !getPeer()->amChoking(); }
 
-void BtChokeMessage::onSendComplete()
+namespace {
+struct ThisProgressUpdate : public ProgressUpdate {
+  ThisProgressUpdate(std::shared_ptr<Peer> peer, BtMessageDispatcher* disp)
+      : peer(std::move(peer)), disp(disp)
+  {
+  }
+  virtual void update(size_t length, bool complete) CXX11_OVERRIDE
+  {
+    if (complete) {
+      peer->amChoking(true);
+      disp->doChokingAction();
+    }
+  }
+  std::shared_ptr<Peer> peer;
+  BtMessageDispatcher* disp;
+};
+} // namespace
+
+std::unique_ptr<ProgressUpdate> BtChokeMessage::getProgressUpdate()
 {
-  peer->amChoking(true);
-  dispatcher->doChokingAction();
+  return make_unique<ThisProgressUpdate>(getPeer(), getBtMessageDispatcher());
 }
 
 } // namespace aria2
