@@ -56,6 +56,7 @@ private:
   DHTTaskQueue* taskQueue_;
 
   DHTTaskFactory* taskFactory_;
+
 public:
   BtPortMessage(uint16_t port);
 
@@ -65,15 +66,16 @@ public:
 
   uint16_t getPort() const { return port_; }
 
-  static BtPortMessage* create(const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtPortMessage> create(const unsigned char* data,
+                                               size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual unsigned char* createMessage();
+  virtual unsigned char* createMessage() CXX11_OVERRIDE;
 
-  virtual size_t getMessageLength();
+  virtual size_t getMessageLength() CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 
   void setLocalNode(DHTNode* localNode);
 
