@@ -55,16 +55,15 @@ class RequestGroup;
 class Signature;
 class FileEntry;
 
-class DownloadContext
-{
+class DownloadContext {
 private:
   std::unique_ptr<Signature> signature_;
 
   RequestGroup* ownerRequestGroup_;
 
-  std::vector<std::unique_ptr<ContextAttribute> > attrs_;
+  std::vector<std::unique_ptr<ContextAttribute>> attrs_;
 
-  std::vector<std::shared_ptr<FileEntry> > fileEntries_;
+  std::vector<std::shared_ptr<FileEntry>> fileEntries_;
 
   std::vector<std::string> pieceHashes_;
 
@@ -95,9 +94,8 @@ public:
 
   // Convenient constructor that creates single file download.  path
   // should be escaped with util::escapePath(...).
-  DownloadContext(int32_t pieceLength,
-                  int64_t totalLength,
-                  const std::string& path = A2STR::NIL);
+  DownloadContext(int32_t pieceLength, int64_t totalLength,
+                  std::string path = A2STR::NIL);
 
   ~DownloadContext();
 
@@ -108,10 +106,9 @@ public:
     return pieceHashes_;
   }
 
-  template<typename InputIterator>
-  void setPieceHashes
-  (const std::string& hashType,
-   InputIterator first, InputIterator last)
+  template <typename InputIterator>
+  void setPieceHashes(const std::string& hashType, InputIterator first,
+                      InputIterator last)
   {
     pieceHashType_ = hashType;
     pieceHashes_.assign(first, last);
@@ -125,7 +122,7 @@ public:
 
   void markTotalLengthIsKnown() { knowsTotalLength_ = true; }
 
-  const std::vector<std::shared_ptr<FileEntry> >& getFileEntries() const
+  const std::vector<std::shared_ptr<FileEntry>>& getFileEntries() const
   {
     return fileEntries_;
   }
@@ -143,7 +140,7 @@ public:
 
   size_t countRequestedFileEntry() const;
 
-  template<typename InputIterator>
+  template <typename InputIterator>
   void setFileEntries(InputIterator first, InputIterator last)
   {
     fileEntries_.assign(first, last);
@@ -177,13 +174,10 @@ public:
 
   RequestGroup* getOwnerRequestGroup() { return ownerRequestGroup_; }
 
-  void setOwnerRequestGroup(RequestGroup* owner)
-  {
-    ownerRequestGroup_ = owner;
-  }
+  void setOwnerRequestGroup(RequestGroup* owner) { ownerRequestGroup_ = owner; }
 
   // sgl must be normalized before the call.
-  void setFileFilter(SegList<int>& sgl);
+  void setFileFilter(SegList<int> sgl);
 
   // Sets file path for specified index. index starts from 1. The
   // index is the same used in setFileFilter(). path is not escaped by
@@ -200,16 +194,13 @@ public:
   // Returns true if piece hash(not whole file hash) is available.
   bool isPieceHashVerificationAvailable() const;
 
-  void setChecksumVerified(bool f)
-  {
-    checksumVerified_ = f;
-  }
+  void setChecksumVerified(bool f) { checksumVerified_ = f; }
 
-  void setAttribute
-  (ContextAttributeType key, std::unique_ptr<ContextAttribute> value);
+  void setAttribute(ContextAttributeType key,
+                    std::unique_ptr<ContextAttribute> value);
 
-  const std::unique_ptr<ContextAttribute>& getAttribute
-  (ContextAttributeType key);
+  const std::unique_ptr<ContextAttribute>&
+  getAttribute(ContextAttributeType key);
 
   bool hasAttribute(ContextAttributeType key) const;
 
@@ -217,12 +208,9 @@ public:
 
   void resetDownloadStopTime();
 
-  const Timer& getDownloadStopTime() const
-  {
-    return downloadStopTime_;
-  }
+  const Timer& getDownloadStopTime() const { return downloadStopTime_; }
 
-  int64_t calculateSessionTime() const;
+  Timer::Clock::duration calculateSessionTime() const;
 
   // Returns FileEntry at given offset. std::shared_ptr<FileEntry>() is
   // returned if no such FileEntry is found.
@@ -230,27 +218,19 @@ public:
 
   void releaseRuntimeResource();
 
-  void setAcceptMetalink(bool f)
-  {
-    acceptMetalink_ = f;
-  }
-  bool getAcceptMetalink() const
-  {
-    return acceptMetalink_;
-  }
+  void setAcceptMetalink(bool f) { acceptMetalink_ = f; }
+  bool getAcceptMetalink() const { return acceptMetalink_; }
 
-  NetStat& getNetStat()
-  {
-    return netStat_;
-  }
+  NetStat& getNetStat() { return netStat_; }
 
   // This method also updates global download length held by
   // RequestGroupMan via getOwnerRequestGroup().
-  void updateDownloadLength(size_t bytes);
+  void updateDownload(size_t bytes);
 
   // This method also updates global upload length held by
   // RequestGroupMan via getOwnerRequestGroup().
   void updateUploadLength(size_t bytes);
+  void updateUploadSpeed(size_t bytes);
 };
 
 } // namespace aria2
