@@ -38,29 +38,28 @@
 #include "HttpConnection.h"
 #include "HttpRequest.h"
 #include "Segment.h"
-#include "Socket.h"
+#include "SocketCore.h"
+#include "SocketRecvBuffer.h"
 
 namespace aria2 {
 
-HttpProxyResponseCommand::HttpProxyResponseCommand
-(cuid_t cuid,
- const SharedHandle<Request>& req,
- const SharedHandle<FileEntry>& fileEntry,
- RequestGroup* requestGroup,
- const HttpConnectionHandle& httpConnection,
- DownloadEngine* e,
- const SocketHandle& s)
-  :AbstractProxyResponseCommand(cuid, req, fileEntry, requestGroup,
-                                httpConnection, e, s)
-{}
+HttpProxyResponseCommand::HttpProxyResponseCommand(
+    cuid_t cuid, const std::shared_ptr<Request>& req,
+    const std::shared_ptr<FileEntry>& fileEntry, RequestGroup* requestGroup,
+    const std::shared_ptr<HttpConnection>& httpConnection, DownloadEngine* e,
+    const std::shared_ptr<SocketCore>& s)
+    : AbstractProxyResponseCommand(cuid, req, fileEntry, requestGroup,
+                                   httpConnection, e, s)
+{
+}
 
 HttpProxyResponseCommand::~HttpProxyResponseCommand() {}
 
-Command* HttpProxyResponseCommand::getNextCommand()
+std::unique_ptr<Command> HttpProxyResponseCommand::getNextCommand()
 {
-  return new HttpRequestCommand(getCuid(), getRequest(), getFileEntry(),
-                                getRequestGroup(), getHttpConnection(),
-                                getDownloadEngine(), getSocket());
+  return make_unique<HttpRequestCommand>(
+      getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+      getHttpConnection(), getDownloadEngine(), getSocket());
 }
 
 } // namespace aria2
