@@ -36,45 +36,39 @@
 #include "common.h"
 
 #include <string>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
 class SocketCore;
-class Logger;
-class LpdMessage;
+struct LpdMessage;
 
 class LpdMessageReceiver {
 private:
-  SharedHandle<SocketCore> socket_;
+  std::shared_ptr<SocketCore> socket_;
   std::string multicastAddress_;
   uint16_t multicastPort_;
   std::string localAddress_;
-  Logger* logger_;
+
 public:
   // Currently only IPv4 multicastAddresses are supported.
-  LpdMessageReceiver
-  (const std::string& multicastAddress, uint16_t multicastPort);
+  LpdMessageReceiver(const std::string& multicastAddress,
+                     uint16_t multicastPort);
+
+  ~LpdMessageReceiver();
 
   // No throw.
   bool init(const std::string& localAddr);
 
   // Receives LPD message and returns LpdMessage which contains
   // sender(peer) and infohash. If no data is available on socket,
-  // returns SharedHandle<LpdMessage>().  If received data is bad,
-  // then returns SharedHandle<LpdMessage>(new LpdMessage())
-  SharedHandle<LpdMessage> receiveMessage();
+  // returns std::shared_ptr<LpdMessage>().  If received data is bad,
+  // they are just skipped.
+  std::unique_ptr<LpdMessage> receiveMessage();
 
-  const SharedHandle<SocketCore>& getSocket() const
-  {
-    return socket_;
-  }
+  const std::shared_ptr<SocketCore>& getSocket() const { return socket_; }
 
-  const std::string& getLocalAddress() const
-  {
-    return localAddress_;
-  }
+  const std::string& getLocalAddress() const { return localAddress_; }
 };
 
 } // namespace aria2
