@@ -37,28 +37,25 @@
 
 namespace aria2 {
 
-const unsigned char* ZeroBtMessage::getMessage()
+ZeroBtMessage::ZeroBtMessage(uint8_t id, const char* name)
+    : SimpleBtMessage{id, name}
 {
-  if(!_msg) {
-    /**
-     * len --- 1, 4bytes
-     * id --- ?, 1byte
-     * total: 5bytes
-     */
-    _msg = new unsigned char[MESSAGE_LENGTH];
-    bittorrent::createPeerMessageString(_msg, MESSAGE_LENGTH, 1, getId());
-  }
-  return _msg;
 }
 
-size_t ZeroBtMessage::getMessageLength()
+unsigned char* ZeroBtMessage::createMessage()
 {
-  return MESSAGE_LENGTH;
+  /**
+   * len --- 1, 4bytes
+   * id --- ?, 1byte
+   * total: 5bytes
+   */
+  auto msg = new unsigned char[MESSAGE_LENGTH];
+  bittorrent::createPeerMessageString(msg, MESSAGE_LENGTH, 1, getId());
+  return msg;
 }
 
-std::string ZeroBtMessage::toString() const
-{
-  return getName();
-}
+size_t ZeroBtMessage::getMessageLength() { return MESSAGE_LENGTH; }
+
+std::string ZeroBtMessage::toString() const { return getName(); }
 
 } // namespace aria2
